@@ -3,7 +3,8 @@ package resources
 import (
 	"testing"
 
-	"github.com/aws/aws-sdk-go/service/ec2"
+	"github.com/aws/aws-sdk-go/service/ec2" //nolint:staticcheck
+
 	"github.com/gotidy/ptr"
 	"github.com/stretchr/testify/assert"
 )
